GmailSSO class
Constructors
- GmailSSO()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exchangeAuthTokenForJWT(
String authToken) → Future< String?> - Exchanges the authorization token for a JWT from the backend
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signInAndGetJWT(
BuildContext context) → Future< String?> - Sign in with Google and exchange the token for JWT
-
signInWithGoogle(
BuildContext context) → Future< String?> - Signs the user in with Google and returns the authorization token
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited